import numpy
import pydrake.autodiffutils
import pydrake.autodiffutils as _ad
import pydrake.math
import pydrake.symbolic
import pydrake.symbolic as _sym
from pydrake.common.cpp_template import SpatialAcceleration_ as SpatialAcceleration_, SpatialForce_ as SpatialForce_, SpatialMomentum_ as SpatialMomentum_, SpatialVelocity_ as SpatialVelocity_
from typing import Any, Callable, ClassVar, overload

__getattr__: Callable

class SpatialAcceleration:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, alpha: numpy.ndarray[numpy.float64[3, 1]], a: numpy.ndarray[numpy.float64[3, 1]]) -> None: ...
    @overload
    def __init__(self, A: numpy.ndarray[numpy.float64[6, 1]]) -> None: ...
    def ComposeWithMovingFrameAcceleration(self, position_of_moving_frame: numpy.ndarray[numpy.float64[3, 1]], angular_velocity_of_this_frame: numpy.ndarray[numpy.float64[3, 1]], velocity_of_moving_frame: SpatialVelocity, acceleration_of_moving_frame: SpatialAcceleration) -> SpatialAcceleration: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix) -> SpatialAcceleration: ...
    def SetZero(self) -> SpatialAcceleration: ...
    def Shift(self, offset: numpy.ndarray[numpy.float64[3, 1]], angular_velocity_of_this_frame: numpy.ndarray[numpy.float64[3, 1]]) -> SpatialAcceleration: ...
    def ShiftWithZeroAngularVelocity(self, offset: numpy.ndarray[numpy.float64[3, 1]]) -> SpatialAcceleration: ...
    @staticmethod
    def Zero() -> SpatialAcceleration: ...
    def get_coeffs(self) -> numpy.ndarray[numpy.float64[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[numpy.float64[3, 1]]: ...
    def translational(self) -> numpy.ndarray[numpy.float64[3, 1]]: ...
    def __add__(self, arg0: SpatialAcceleration) -> SpatialAcceleration: ...
    def __copy__(self) -> SpatialAcceleration: ...
    def __deepcopy__(self, arg0: dict) -> SpatialAcceleration: ...
    def __iadd__(self, arg0: SpatialAcceleration) -> SpatialAcceleration: ...
    def __imul__(self, arg0: float) -> SpatialAcceleration: ...
    def __isub__(self, arg0: SpatialAcceleration) -> SpatialAcceleration: ...
    def __mul__(self, arg0: float) -> SpatialAcceleration: ...
    def __neg__(self) -> SpatialAcceleration: ...
    def __rmul__(self, arg0: float) -> SpatialAcceleration: ...
    def __sub__(self, arg0: SpatialAcceleration) -> SpatialAcceleration: ...

class SpatialAcceleration_𝓣AutoDiffXd𝓤:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, alpha: numpy.ndarray[object[3, 1]], a: numpy.ndarray[object[3, 1]]) -> None: ...
    @overload
    def __init__(self, A: numpy.ndarray[object[6, 1]]) -> None: ...
    def ComposeWithMovingFrameAcceleration(self, position_of_moving_frame: numpy.ndarray[object[3, 1]], angular_velocity_of_this_frame: numpy.ndarray[object[3, 1]], velocity_of_moving_frame: SpatialVelocity_TAutoDiffXdU, acceleration_of_moving_frame: SpatialAcceleration_TAutoDiffXdU) -> SpatialAcceleration_TAutoDiffXdU: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix_TAutoDiffXdU) -> SpatialAcceleration_TAutoDiffXdU: ...
    def SetZero(self) -> SpatialAcceleration_TAutoDiffXdU: ...
    def Shift(self, offset: numpy.ndarray[object[3, 1]], angular_velocity_of_this_frame: numpy.ndarray[object[3, 1]]) -> SpatialAcceleration_TAutoDiffXdU: ...
    def ShiftWithZeroAngularVelocity(self, offset: numpy.ndarray[object[3, 1]]) -> SpatialAcceleration_TAutoDiffXdU: ...
    @staticmethod
    def Zero() -> SpatialAcceleration_TAutoDiffXdU: ...
    def get_coeffs(self) -> numpy.ndarray[object[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[object[3, 1]]: ...
    def translational(self) -> numpy.ndarray[object[3, 1]]: ...
    def __add__(self, arg0: SpatialAcceleration_TAutoDiffXdU) -> SpatialAcceleration_TAutoDiffXdU: ...
    def __copy__(self) -> SpatialAcceleration_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> SpatialAcceleration_TAutoDiffXdU: ...
    def __iadd__(self, arg0: SpatialAcceleration_TAutoDiffXdU) -> SpatialAcceleration_TAutoDiffXdU: ...
    def __imul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialAcceleration_TAutoDiffXdU: ...
    def __isub__(self, arg0: SpatialAcceleration_TAutoDiffXdU) -> SpatialAcceleration_TAutoDiffXdU: ...
    def __mul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialAcceleration_TAutoDiffXdU: ...
    def __neg__(self) -> SpatialAcceleration_TAutoDiffXdU: ...
    def __rmul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialAcceleration_TAutoDiffXdU: ...
    def __sub__(self, arg0: SpatialAcceleration_TAutoDiffXdU) -> SpatialAcceleration_TAutoDiffXdU: ...

class SpatialAcceleration_𝓣Expression𝓤:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, alpha: numpy.ndarray[object[3, 1]], a: numpy.ndarray[object[3, 1]]) -> None: ...
    @overload
    def __init__(self, A: numpy.ndarray[object[6, 1]]) -> None: ...
    def ComposeWithMovingFrameAcceleration(self, position_of_moving_frame: numpy.ndarray[object[3, 1]], angular_velocity_of_this_frame: numpy.ndarray[object[3, 1]], velocity_of_moving_frame: SpatialVelocity_TExpressionU, acceleration_of_moving_frame: SpatialAcceleration_TExpressionU) -> SpatialAcceleration_TExpressionU: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix_TExpressionU) -> SpatialAcceleration_TExpressionU: ...
    def SetZero(self) -> SpatialAcceleration_TExpressionU: ...
    def Shift(self, offset: numpy.ndarray[object[3, 1]], angular_velocity_of_this_frame: numpy.ndarray[object[3, 1]]) -> SpatialAcceleration_TExpressionU: ...
    def ShiftWithZeroAngularVelocity(self, offset: numpy.ndarray[object[3, 1]]) -> SpatialAcceleration_TExpressionU: ...
    @staticmethod
    def Zero() -> SpatialAcceleration_TExpressionU: ...
    def get_coeffs(self) -> numpy.ndarray[object[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[object[3, 1]]: ...
    def translational(self) -> numpy.ndarray[object[3, 1]]: ...
    def __add__(self, arg0: SpatialAcceleration_TExpressionU) -> SpatialAcceleration_TExpressionU: ...
    def __copy__(self) -> SpatialAcceleration_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> SpatialAcceleration_TExpressionU: ...
    def __iadd__(self, arg0: SpatialAcceleration_TExpressionU) -> SpatialAcceleration_TExpressionU: ...
    def __imul__(self, arg0: pydrake.symbolic.Expression) -> SpatialAcceleration_TExpressionU: ...
    def __isub__(self, arg0: SpatialAcceleration_TExpressionU) -> SpatialAcceleration_TExpressionU: ...
    def __mul__(self, arg0: pydrake.symbolic.Expression) -> SpatialAcceleration_TExpressionU: ...
    def __neg__(self) -> SpatialAcceleration_TExpressionU: ...
    def __rmul__(self, arg0: pydrake.symbolic.Expression) -> SpatialAcceleration_TExpressionU: ...
    def __sub__(self, arg0: SpatialAcceleration_TExpressionU) -> SpatialAcceleration_TExpressionU: ...

class SpatialForce:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, tau: numpy.ndarray[numpy.float64[3, 1]], f: numpy.ndarray[numpy.float64[3, 1]]) -> None: ...
    @overload
    def __init__(self, F: numpy.ndarray[numpy.float64[6, 1]]) -> None: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix) -> SpatialForce: ...
    def SetZero(self) -> SpatialForce: ...
    @overload
    def Shift(self, offset: numpy.ndarray[numpy.float64[3, 1]]) -> SpatialForce: ...
    @overload
    def Shift(self) -> Any: ...
    @staticmethod
    def Zero() -> SpatialForce: ...
    def dot(self, velocity: SpatialVelocity) -> float: ...
    def get_coeffs(self) -> numpy.ndarray[numpy.float64[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[numpy.float64[3, 1]]: ...
    def translational(self) -> numpy.ndarray[numpy.float64[3, 1]]: ...
    def __add__(self, arg0: SpatialForce) -> SpatialForce: ...
    def __copy__(self) -> SpatialForce: ...
    def __deepcopy__(self, arg0: dict) -> SpatialForce: ...
    def __iadd__(self, arg0: SpatialForce) -> SpatialForce: ...
    def __imul__(self, arg0: float) -> SpatialForce: ...
    def __isub__(self, arg0: SpatialForce) -> SpatialForce: ...
    def __matmul__(self, *args, **kwargs): ...
    def __mul__(self, arg0: float) -> SpatialForce: ...
    def __neg__(self) -> SpatialForce: ...
    def __rmul__(self, arg0: float) -> SpatialForce: ...
    def __sub__(self, arg0: SpatialForce) -> SpatialForce: ...

class SpatialForce_𝓣AutoDiffXd𝓤:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, tau: numpy.ndarray[object[3, 1]], f: numpy.ndarray[object[3, 1]]) -> None: ...
    @overload
    def __init__(self, F: numpy.ndarray[object[6, 1]]) -> None: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix_TAutoDiffXdU) -> SpatialForce_TAutoDiffXdU: ...
    def SetZero(self) -> SpatialForce_TAutoDiffXdU: ...
    @overload
    def Shift(self, offset: numpy.ndarray[object[3, 1]]) -> SpatialForce_TAutoDiffXdU: ...
    @overload
    def Shift(self) -> Any: ...
    @staticmethod
    def Zero() -> SpatialForce_TAutoDiffXdU: ...
    def dot(self, velocity: SpatialVelocity_TAutoDiffXdU) -> pydrake.autodiffutils.AutoDiffXd: ...
    def get_coeffs(self) -> numpy.ndarray[object[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[object[3, 1]]: ...
    def translational(self) -> numpy.ndarray[object[3, 1]]: ...
    def __add__(self, arg0: SpatialForce_TAutoDiffXdU) -> SpatialForce_TAutoDiffXdU: ...
    def __copy__(self) -> SpatialForce_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> SpatialForce_TAutoDiffXdU: ...
    def __iadd__(self, arg0: SpatialForce_TAutoDiffXdU) -> SpatialForce_TAutoDiffXdU: ...
    def __imul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialForce_TAutoDiffXdU: ...
    def __isub__(self, arg0: SpatialForce_TAutoDiffXdU) -> SpatialForce_TAutoDiffXdU: ...
    def __matmul__(self, *args, **kwargs): ...
    def __mul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialForce_TAutoDiffXdU: ...
    def __neg__(self) -> SpatialForce_TAutoDiffXdU: ...
    def __rmul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialForce_TAutoDiffXdU: ...
    def __sub__(self, arg0: SpatialForce_TAutoDiffXdU) -> SpatialForce_TAutoDiffXdU: ...

class SpatialForce_𝓣Expression𝓤:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, tau: numpy.ndarray[object[3, 1]], f: numpy.ndarray[object[3, 1]]) -> None: ...
    @overload
    def __init__(self, F: numpy.ndarray[object[6, 1]]) -> None: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix_TExpressionU) -> SpatialForce_TExpressionU: ...
    def SetZero(self) -> SpatialForce_TExpressionU: ...
    @overload
    def Shift(self, offset: numpy.ndarray[object[3, 1]]) -> SpatialForce_TExpressionU: ...
    @overload
    def Shift(self) -> Any: ...
    @staticmethod
    def Zero() -> SpatialForce_TExpressionU: ...
    def dot(self, velocity: SpatialVelocity_TExpressionU) -> pydrake.symbolic.Expression: ...
    def get_coeffs(self) -> numpy.ndarray[object[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[object[3, 1]]: ...
    def translational(self) -> numpy.ndarray[object[3, 1]]: ...
    def __add__(self, arg0: SpatialForce_TExpressionU) -> SpatialForce_TExpressionU: ...
    def __copy__(self) -> SpatialForce_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> SpatialForce_TExpressionU: ...
    def __iadd__(self, arg0: SpatialForce_TExpressionU) -> SpatialForce_TExpressionU: ...
    def __imul__(self, arg0: pydrake.symbolic.Expression) -> SpatialForce_TExpressionU: ...
    def __isub__(self, arg0: SpatialForce_TExpressionU) -> SpatialForce_TExpressionU: ...
    def __matmul__(self, *args, **kwargs): ...
    def __mul__(self, arg0: pydrake.symbolic.Expression) -> SpatialForce_TExpressionU: ...
    def __neg__(self) -> SpatialForce_TExpressionU: ...
    def __rmul__(self, arg0: pydrake.symbolic.Expression) -> SpatialForce_TExpressionU: ...
    def __sub__(self, arg0: SpatialForce_TExpressionU) -> SpatialForce_TExpressionU: ...

class SpatialMomentum:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, h: numpy.ndarray[numpy.float64[3, 1]], l: numpy.ndarray[numpy.float64[3, 1]]) -> None: ...
    @overload
    def __init__(self, L: numpy.ndarray[numpy.float64[6, 1]]) -> None: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix) -> SpatialMomentum: ...
    def SetZero(self) -> SpatialMomentum: ...
    def Shift(self, offset: numpy.ndarray[numpy.float64[3, 1]]) -> SpatialMomentum: ...
    @staticmethod
    def Zero() -> SpatialMomentum: ...
    def dot(self, velocity: SpatialVelocity) -> float: ...
    def get_coeffs(self) -> numpy.ndarray[numpy.float64[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[numpy.float64[3, 1]]: ...
    def translational(self) -> numpy.ndarray[numpy.float64[3, 1]]: ...
    def __add__(self, arg0: SpatialMomentum) -> SpatialMomentum: ...
    def __copy__(self) -> SpatialMomentum: ...
    def __deepcopy__(self, arg0: dict) -> SpatialMomentum: ...
    def __iadd__(self, arg0: SpatialMomentum) -> SpatialMomentum: ...
    def __imul__(self, arg0: float) -> SpatialMomentum: ...
    def __isub__(self, arg0: SpatialMomentum) -> SpatialMomentum: ...
    def __matmul__(self, *args, **kwargs): ...
    def __mul__(self, arg0: float) -> SpatialMomentum: ...
    def __neg__(self) -> SpatialMomentum: ...
    def __rmul__(self, arg0: float) -> SpatialMomentum: ...
    def __sub__(self, arg0: SpatialMomentum) -> SpatialMomentum: ...

class SpatialMomentum_𝓣AutoDiffXd𝓤:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, h: numpy.ndarray[object[3, 1]], l: numpy.ndarray[object[3, 1]]) -> None: ...
    @overload
    def __init__(self, L: numpy.ndarray[object[6, 1]]) -> None: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix_TAutoDiffXdU) -> SpatialMomentum_TAutoDiffXdU: ...
    def SetZero(self) -> SpatialMomentum_TAutoDiffXdU: ...
    def Shift(self, offset: numpy.ndarray[object[3, 1]]) -> SpatialMomentum_TAutoDiffXdU: ...
    @staticmethod
    def Zero() -> SpatialMomentum_TAutoDiffXdU: ...
    def dot(self, velocity: SpatialVelocity_TAutoDiffXdU) -> pydrake.autodiffutils.AutoDiffXd: ...
    def get_coeffs(self) -> numpy.ndarray[object[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[object[3, 1]]: ...
    def translational(self) -> numpy.ndarray[object[3, 1]]: ...
    def __add__(self, arg0: SpatialMomentum_TAutoDiffXdU) -> SpatialMomentum_TAutoDiffXdU: ...
    def __copy__(self) -> SpatialMomentum_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> SpatialMomentum_TAutoDiffXdU: ...
    def __iadd__(self, arg0: SpatialMomentum_TAutoDiffXdU) -> SpatialMomentum_TAutoDiffXdU: ...
    def __imul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialMomentum_TAutoDiffXdU: ...
    def __isub__(self, arg0: SpatialMomentum_TAutoDiffXdU) -> SpatialMomentum_TAutoDiffXdU: ...
    def __matmul__(self, *args, **kwargs): ...
    def __mul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialMomentum_TAutoDiffXdU: ...
    def __neg__(self) -> SpatialMomentum_TAutoDiffXdU: ...
    def __rmul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialMomentum_TAutoDiffXdU: ...
    def __sub__(self, arg0: SpatialMomentum_TAutoDiffXdU) -> SpatialMomentum_TAutoDiffXdU: ...

class SpatialMomentum_𝓣Expression𝓤:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, h: numpy.ndarray[object[3, 1]], l: numpy.ndarray[object[3, 1]]) -> None: ...
    @overload
    def __init__(self, L: numpy.ndarray[object[6, 1]]) -> None: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix_TExpressionU) -> SpatialMomentum_TExpressionU: ...
    def SetZero(self) -> SpatialMomentum_TExpressionU: ...
    def Shift(self, offset: numpy.ndarray[object[3, 1]]) -> SpatialMomentum_TExpressionU: ...
    @staticmethod
    def Zero() -> SpatialMomentum_TExpressionU: ...
    def dot(self, velocity: SpatialVelocity_TExpressionU) -> pydrake.symbolic.Expression: ...
    def get_coeffs(self) -> numpy.ndarray[object[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[object[3, 1]]: ...
    def translational(self) -> numpy.ndarray[object[3, 1]]: ...
    def __add__(self, arg0: SpatialMomentum_TExpressionU) -> SpatialMomentum_TExpressionU: ...
    def __copy__(self) -> SpatialMomentum_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> SpatialMomentum_TExpressionU: ...
    def __iadd__(self, arg0: SpatialMomentum_TExpressionU) -> SpatialMomentum_TExpressionU: ...
    def __imul__(self, arg0: pydrake.symbolic.Expression) -> SpatialMomentum_TExpressionU: ...
    def __isub__(self, arg0: SpatialMomentum_TExpressionU) -> SpatialMomentum_TExpressionU: ...
    def __matmul__(self, *args, **kwargs): ...
    def __mul__(self, arg0: pydrake.symbolic.Expression) -> SpatialMomentum_TExpressionU: ...
    def __neg__(self) -> SpatialMomentum_TExpressionU: ...
    def __rmul__(self, arg0: pydrake.symbolic.Expression) -> SpatialMomentum_TExpressionU: ...
    def __sub__(self, arg0: SpatialMomentum_TExpressionU) -> SpatialMomentum_TExpressionU: ...

class SpatialVelocity:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, w: numpy.ndarray[numpy.float64[3, 1]], v: numpy.ndarray[numpy.float64[3, 1]]) -> None: ...
    @overload
    def __init__(self, V: numpy.ndarray[numpy.float64[6, 1]]) -> None: ...
    def ComposeWithMovingFrameVelocity(self, position_of_moving_frame: numpy.ndarray[numpy.float64[3, 1]], velocity_of_moving_frame: SpatialVelocity) -> SpatialVelocity: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix) -> SpatialVelocity: ...
    def SetZero(self) -> SpatialVelocity: ...
    def Shift(self, offset: numpy.ndarray[numpy.float64[3, 1]]) -> SpatialVelocity: ...
    @staticmethod
    def Zero() -> SpatialVelocity: ...
    def dot(self, force: SpatialForce) -> float: ...
    def get_coeffs(self) -> numpy.ndarray[numpy.float64[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[numpy.float64[3, 1]]: ...
    def translational(self) -> numpy.ndarray[numpy.float64[3, 1]]: ...
    def __add__(self, arg0: SpatialVelocity) -> SpatialVelocity: ...
    def __copy__(self) -> SpatialVelocity: ...
    def __deepcopy__(self, arg0: dict) -> SpatialVelocity: ...
    def __iadd__(self, arg0: SpatialVelocity) -> SpatialVelocity: ...
    def __imul__(self, arg0: float) -> SpatialVelocity: ...
    def __isub__(self, arg0: SpatialVelocity) -> SpatialVelocity: ...
    def __matmul__(self, *args, **kwargs): ...
    def __mul__(self, arg0: float) -> SpatialVelocity: ...
    def __neg__(self) -> SpatialVelocity: ...
    def __rmul__(self, arg0: float) -> SpatialVelocity: ...
    def __sub__(self, arg0: SpatialVelocity) -> SpatialVelocity: ...

class SpatialVelocity_𝓣AutoDiffXd𝓤:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, w: numpy.ndarray[object[3, 1]], v: numpy.ndarray[object[3, 1]]) -> None: ...
    @overload
    def __init__(self, V: numpy.ndarray[object[6, 1]]) -> None: ...
    def ComposeWithMovingFrameVelocity(self, position_of_moving_frame: numpy.ndarray[object[3, 1]], velocity_of_moving_frame: SpatialVelocity_TAutoDiffXdU) -> SpatialVelocity_TAutoDiffXdU: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix_TAutoDiffXdU) -> SpatialVelocity_TAutoDiffXdU: ...
    def SetZero(self) -> SpatialVelocity_TAutoDiffXdU: ...
    def Shift(self, offset: numpy.ndarray[object[3, 1]]) -> SpatialVelocity_TAutoDiffXdU: ...
    @staticmethod
    def Zero() -> SpatialVelocity_TAutoDiffXdU: ...
    def dot(self, force: SpatialForce_TAutoDiffXdU) -> pydrake.autodiffutils.AutoDiffXd: ...
    def get_coeffs(self) -> numpy.ndarray[object[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[object[3, 1]]: ...
    def translational(self) -> numpy.ndarray[object[3, 1]]: ...
    def __add__(self, arg0: SpatialVelocity_TAutoDiffXdU) -> SpatialVelocity_TAutoDiffXdU: ...
    def __copy__(self) -> SpatialVelocity_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> SpatialVelocity_TAutoDiffXdU: ...
    def __iadd__(self, arg0: SpatialVelocity_TAutoDiffXdU) -> SpatialVelocity_TAutoDiffXdU: ...
    def __imul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialVelocity_TAutoDiffXdU: ...
    def __isub__(self, arg0: SpatialVelocity_TAutoDiffXdU) -> SpatialVelocity_TAutoDiffXdU: ...
    def __matmul__(self, *args, **kwargs): ...
    def __mul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialVelocity_TAutoDiffXdU: ...
    def __neg__(self) -> SpatialVelocity_TAutoDiffXdU: ...
    def __rmul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialVelocity_TAutoDiffXdU: ...
    def __sub__(self, arg0: SpatialVelocity_TAutoDiffXdU) -> SpatialVelocity_TAutoDiffXdU: ...

class SpatialVelocity_𝓣Expression𝓤:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, w: numpy.ndarray[object[3, 1]], v: numpy.ndarray[object[3, 1]]) -> None: ...
    @overload
    def __init__(self, V: numpy.ndarray[object[6, 1]]) -> None: ...
    def ComposeWithMovingFrameVelocity(self, position_of_moving_frame: numpy.ndarray[object[3, 1]], velocity_of_moving_frame: SpatialVelocity_TExpressionU) -> SpatialVelocity_TExpressionU: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix_TExpressionU) -> SpatialVelocity_TExpressionU: ...
    def SetZero(self) -> SpatialVelocity_TExpressionU: ...
    def Shift(self, offset: numpy.ndarray[object[3, 1]]) -> SpatialVelocity_TExpressionU: ...
    @staticmethod
    def Zero() -> SpatialVelocity_TExpressionU: ...
    def dot(self, force: SpatialForce_TExpressionU) -> pydrake.symbolic.Expression: ...
    def get_coeffs(self) -> numpy.ndarray[object[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[object[3, 1]]: ...
    def translational(self) -> numpy.ndarray[object[3, 1]]: ...
    def __add__(self, arg0: SpatialVelocity_TExpressionU) -> SpatialVelocity_TExpressionU: ...
    def __copy__(self) -> SpatialVelocity_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> SpatialVelocity_TExpressionU: ...
    def __iadd__(self, arg0: SpatialVelocity_TExpressionU) -> SpatialVelocity_TExpressionU: ...
    def __imul__(self, arg0: pydrake.symbolic.Expression) -> SpatialVelocity_TExpressionU: ...
    def __isub__(self, arg0: SpatialVelocity_TExpressionU) -> SpatialVelocity_TExpressionU: ...
    def __matmul__(self, *args, **kwargs): ...
    def __mul__(self, arg0: pydrake.symbolic.Expression) -> SpatialVelocity_TExpressionU: ...
    def __neg__(self) -> SpatialVelocity_TExpressionU: ...
    def __rmul__(self, arg0: pydrake.symbolic.Expression) -> SpatialVelocity_TExpressionU: ...
    def __sub__(self, arg0: SpatialVelocity_TExpressionU) -> SpatialVelocity_TExpressionU: ...

class _TemporaryName_N5drake9multibody12SpatialForceINS_2ad8AutoDiffEEE:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, tau: numpy.ndarray[object[3, 1]], f: numpy.ndarray[object[3, 1]]) -> None: ...
    @overload
    def __init__(self, F: numpy.ndarray[object[6, 1]]) -> None: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix_TAutoDiffXdU) -> SpatialForce_TAutoDiffXdU: ...
    def SetZero(self) -> SpatialForce_TAutoDiffXdU: ...
    @overload
    def Shift(self, offset: numpy.ndarray[object[3, 1]]) -> SpatialForce_TAutoDiffXdU: ...
    @overload
    def Shift(self) -> Any: ...
    @staticmethod
    def Zero() -> SpatialForce_TAutoDiffXdU: ...
    def dot(self, velocity: SpatialVelocity_TAutoDiffXdU) -> pydrake.autodiffutils.AutoDiffXd: ...
    def get_coeffs(self) -> numpy.ndarray[object[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[object[3, 1]]: ...
    def translational(self) -> numpy.ndarray[object[3, 1]]: ...
    def __add__(self, arg0: SpatialForce_TAutoDiffXdU) -> SpatialForce_TAutoDiffXdU: ...
    def __copy__(self) -> SpatialForce_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> SpatialForce_TAutoDiffXdU: ...
    def __iadd__(self, arg0: SpatialForce_TAutoDiffXdU) -> SpatialForce_TAutoDiffXdU: ...
    def __imul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialForce_TAutoDiffXdU: ...
    def __isub__(self, arg0: SpatialForce_TAutoDiffXdU) -> SpatialForce_TAutoDiffXdU: ...
    def __matmul__(self, *args, **kwargs): ...
    def __mul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialForce_TAutoDiffXdU: ...
    def __neg__(self) -> SpatialForce_TAutoDiffXdU: ...
    def __rmul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialForce_TAutoDiffXdU: ...
    def __sub__(self, arg0: SpatialForce_TAutoDiffXdU) -> SpatialForce_TAutoDiffXdU: ...

class _TemporaryName_N5drake9multibody12SpatialForceINS_8symbolic10ExpressionEEE:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, tau: numpy.ndarray[object[3, 1]], f: numpy.ndarray[object[3, 1]]) -> None: ...
    @overload
    def __init__(self, F: numpy.ndarray[object[6, 1]]) -> None: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix_TExpressionU) -> SpatialForce_TExpressionU: ...
    def SetZero(self) -> SpatialForce_TExpressionU: ...
    @overload
    def Shift(self, offset: numpy.ndarray[object[3, 1]]) -> SpatialForce_TExpressionU: ...
    @overload
    def Shift(self) -> Any: ...
    @staticmethod
    def Zero() -> SpatialForce_TExpressionU: ...
    def dot(self, velocity: SpatialVelocity_TExpressionU) -> pydrake.symbolic.Expression: ...
    def get_coeffs(self) -> numpy.ndarray[object[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[object[3, 1]]: ...
    def translational(self) -> numpy.ndarray[object[3, 1]]: ...
    def __add__(self, arg0: SpatialForce_TExpressionU) -> SpatialForce_TExpressionU: ...
    def __copy__(self) -> SpatialForce_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> SpatialForce_TExpressionU: ...
    def __iadd__(self, arg0: SpatialForce_TExpressionU) -> SpatialForce_TExpressionU: ...
    def __imul__(self, arg0: pydrake.symbolic.Expression) -> SpatialForce_TExpressionU: ...
    def __isub__(self, arg0: SpatialForce_TExpressionU) -> SpatialForce_TExpressionU: ...
    def __matmul__(self, *args, **kwargs): ...
    def __mul__(self, arg0: pydrake.symbolic.Expression) -> SpatialForce_TExpressionU: ...
    def __neg__(self) -> SpatialForce_TExpressionU: ...
    def __rmul__(self, arg0: pydrake.symbolic.Expression) -> SpatialForce_TExpressionU: ...
    def __sub__(self, arg0: SpatialForce_TExpressionU) -> SpatialForce_TExpressionU: ...

class _TemporaryName_N5drake9multibody15SpatialMomentumINS_2ad8AutoDiffEEE:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, h: numpy.ndarray[object[3, 1]], l: numpy.ndarray[object[3, 1]]) -> None: ...
    @overload
    def __init__(self, L: numpy.ndarray[object[6, 1]]) -> None: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix_TAutoDiffXdU) -> SpatialMomentum_TAutoDiffXdU: ...
    def SetZero(self) -> SpatialMomentum_TAutoDiffXdU: ...
    def Shift(self, offset: numpy.ndarray[object[3, 1]]) -> SpatialMomentum_TAutoDiffXdU: ...
    @staticmethod
    def Zero() -> SpatialMomentum_TAutoDiffXdU: ...
    def dot(self, velocity: SpatialVelocity_TAutoDiffXdU) -> pydrake.autodiffutils.AutoDiffXd: ...
    def get_coeffs(self) -> numpy.ndarray[object[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[object[3, 1]]: ...
    def translational(self) -> numpy.ndarray[object[3, 1]]: ...
    def __add__(self, arg0: SpatialMomentum_TAutoDiffXdU) -> SpatialMomentum_TAutoDiffXdU: ...
    def __copy__(self) -> SpatialMomentum_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> SpatialMomentum_TAutoDiffXdU: ...
    def __iadd__(self, arg0: SpatialMomentum_TAutoDiffXdU) -> SpatialMomentum_TAutoDiffXdU: ...
    def __imul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialMomentum_TAutoDiffXdU: ...
    def __isub__(self, arg0: SpatialMomentum_TAutoDiffXdU) -> SpatialMomentum_TAutoDiffXdU: ...
    def __matmul__(self, *args, **kwargs): ...
    def __mul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialMomentum_TAutoDiffXdU: ...
    def __neg__(self) -> SpatialMomentum_TAutoDiffXdU: ...
    def __rmul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialMomentum_TAutoDiffXdU: ...
    def __sub__(self, arg0: SpatialMomentum_TAutoDiffXdU) -> SpatialMomentum_TAutoDiffXdU: ...

class _TemporaryName_N5drake9multibody15SpatialMomentumINS_8symbolic10ExpressionEEE:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, h: numpy.ndarray[object[3, 1]], l: numpy.ndarray[object[3, 1]]) -> None: ...
    @overload
    def __init__(self, L: numpy.ndarray[object[6, 1]]) -> None: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix_TExpressionU) -> SpatialMomentum_TExpressionU: ...
    def SetZero(self) -> SpatialMomentum_TExpressionU: ...
    def Shift(self, offset: numpy.ndarray[object[3, 1]]) -> SpatialMomentum_TExpressionU: ...
    @staticmethod
    def Zero() -> SpatialMomentum_TExpressionU: ...
    def dot(self, velocity: SpatialVelocity_TExpressionU) -> pydrake.symbolic.Expression: ...
    def get_coeffs(self) -> numpy.ndarray[object[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[object[3, 1]]: ...
    def translational(self) -> numpy.ndarray[object[3, 1]]: ...
    def __add__(self, arg0: SpatialMomentum_TExpressionU) -> SpatialMomentum_TExpressionU: ...
    def __copy__(self) -> SpatialMomentum_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> SpatialMomentum_TExpressionU: ...
    def __iadd__(self, arg0: SpatialMomentum_TExpressionU) -> SpatialMomentum_TExpressionU: ...
    def __imul__(self, arg0: pydrake.symbolic.Expression) -> SpatialMomentum_TExpressionU: ...
    def __isub__(self, arg0: SpatialMomentum_TExpressionU) -> SpatialMomentum_TExpressionU: ...
    def __matmul__(self, *args, **kwargs): ...
    def __mul__(self, arg0: pydrake.symbolic.Expression) -> SpatialMomentum_TExpressionU: ...
    def __neg__(self) -> SpatialMomentum_TExpressionU: ...
    def __rmul__(self, arg0: pydrake.symbolic.Expression) -> SpatialMomentum_TExpressionU: ...
    def __sub__(self, arg0: SpatialMomentum_TExpressionU) -> SpatialMomentum_TExpressionU: ...

class _TemporaryName_N5drake9multibody15SpatialVelocityINS_2ad8AutoDiffEEE:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, w: numpy.ndarray[object[3, 1]], v: numpy.ndarray[object[3, 1]]) -> None: ...
    @overload
    def __init__(self, V: numpy.ndarray[object[6, 1]]) -> None: ...
    def ComposeWithMovingFrameVelocity(self, position_of_moving_frame: numpy.ndarray[object[3, 1]], velocity_of_moving_frame: SpatialVelocity_TAutoDiffXdU) -> SpatialVelocity_TAutoDiffXdU: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix_TAutoDiffXdU) -> SpatialVelocity_TAutoDiffXdU: ...
    def SetZero(self) -> SpatialVelocity_TAutoDiffXdU: ...
    def Shift(self, offset: numpy.ndarray[object[3, 1]]) -> SpatialVelocity_TAutoDiffXdU: ...
    @staticmethod
    def Zero() -> SpatialVelocity_TAutoDiffXdU: ...
    def dot(self, force: SpatialForce_TAutoDiffXdU) -> pydrake.autodiffutils.AutoDiffXd: ...
    def get_coeffs(self) -> numpy.ndarray[object[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[object[3, 1]]: ...
    def translational(self) -> numpy.ndarray[object[3, 1]]: ...
    def __add__(self, arg0: SpatialVelocity_TAutoDiffXdU) -> SpatialVelocity_TAutoDiffXdU: ...
    def __copy__(self) -> SpatialVelocity_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> SpatialVelocity_TAutoDiffXdU: ...
    def __iadd__(self, arg0: SpatialVelocity_TAutoDiffXdU) -> SpatialVelocity_TAutoDiffXdU: ...
    def __imul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialVelocity_TAutoDiffXdU: ...
    def __isub__(self, arg0: SpatialVelocity_TAutoDiffXdU) -> SpatialVelocity_TAutoDiffXdU: ...
    def __matmul__(self, *args, **kwargs): ...
    def __mul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialVelocity_TAutoDiffXdU: ...
    def __neg__(self) -> SpatialVelocity_TAutoDiffXdU: ...
    def __rmul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialVelocity_TAutoDiffXdU: ...
    def __sub__(self, arg0: SpatialVelocity_TAutoDiffXdU) -> SpatialVelocity_TAutoDiffXdU: ...

class _TemporaryName_N5drake9multibody15SpatialVelocityINS_8symbolic10ExpressionEEE:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, w: numpy.ndarray[object[3, 1]], v: numpy.ndarray[object[3, 1]]) -> None: ...
    @overload
    def __init__(self, V: numpy.ndarray[object[6, 1]]) -> None: ...
    def ComposeWithMovingFrameVelocity(self, position_of_moving_frame: numpy.ndarray[object[3, 1]], velocity_of_moving_frame: SpatialVelocity_TExpressionU) -> SpatialVelocity_TExpressionU: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix_TExpressionU) -> SpatialVelocity_TExpressionU: ...
    def SetZero(self) -> SpatialVelocity_TExpressionU: ...
    def Shift(self, offset: numpy.ndarray[object[3, 1]]) -> SpatialVelocity_TExpressionU: ...
    @staticmethod
    def Zero() -> SpatialVelocity_TExpressionU: ...
    def dot(self, force: SpatialForce_TExpressionU) -> pydrake.symbolic.Expression: ...
    def get_coeffs(self) -> numpy.ndarray[object[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[object[3, 1]]: ...
    def translational(self) -> numpy.ndarray[object[3, 1]]: ...
    def __add__(self, arg0: SpatialVelocity_TExpressionU) -> SpatialVelocity_TExpressionU: ...
    def __copy__(self) -> SpatialVelocity_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> SpatialVelocity_TExpressionU: ...
    def __iadd__(self, arg0: SpatialVelocity_TExpressionU) -> SpatialVelocity_TExpressionU: ...
    def __imul__(self, arg0: pydrake.symbolic.Expression) -> SpatialVelocity_TExpressionU: ...
    def __isub__(self, arg0: SpatialVelocity_TExpressionU) -> SpatialVelocity_TExpressionU: ...
    def __matmul__(self, *args, **kwargs): ...
    def __mul__(self, arg0: pydrake.symbolic.Expression) -> SpatialVelocity_TExpressionU: ...
    def __neg__(self) -> SpatialVelocity_TExpressionU: ...
    def __rmul__(self, arg0: pydrake.symbolic.Expression) -> SpatialVelocity_TExpressionU: ...
    def __sub__(self, arg0: SpatialVelocity_TExpressionU) -> SpatialVelocity_TExpressionU: ...

class _TemporaryName_N5drake9multibody19SpatialAccelerationINS_2ad8AutoDiffEEE:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, alpha: numpy.ndarray[object[3, 1]], a: numpy.ndarray[object[3, 1]]) -> None: ...
    @overload
    def __init__(self, A: numpy.ndarray[object[6, 1]]) -> None: ...
    def ComposeWithMovingFrameAcceleration(self, position_of_moving_frame: numpy.ndarray[object[3, 1]], angular_velocity_of_this_frame: numpy.ndarray[object[3, 1]], velocity_of_moving_frame: SpatialVelocity_TAutoDiffXdU, acceleration_of_moving_frame: SpatialAcceleration_TAutoDiffXdU) -> SpatialAcceleration_TAutoDiffXdU: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix_TAutoDiffXdU) -> SpatialAcceleration_TAutoDiffXdU: ...
    def SetZero(self) -> SpatialAcceleration_TAutoDiffXdU: ...
    def Shift(self, offset: numpy.ndarray[object[3, 1]], angular_velocity_of_this_frame: numpy.ndarray[object[3, 1]]) -> SpatialAcceleration_TAutoDiffXdU: ...
    def ShiftWithZeroAngularVelocity(self, offset: numpy.ndarray[object[3, 1]]) -> SpatialAcceleration_TAutoDiffXdU: ...
    @staticmethod
    def Zero() -> SpatialAcceleration_TAutoDiffXdU: ...
    def get_coeffs(self) -> numpy.ndarray[object[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[object[3, 1]]: ...
    def translational(self) -> numpy.ndarray[object[3, 1]]: ...
    def __add__(self, arg0: SpatialAcceleration_TAutoDiffXdU) -> SpatialAcceleration_TAutoDiffXdU: ...
    def __copy__(self) -> SpatialAcceleration_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> SpatialAcceleration_TAutoDiffXdU: ...
    def __iadd__(self, arg0: SpatialAcceleration_TAutoDiffXdU) -> SpatialAcceleration_TAutoDiffXdU: ...
    def __imul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialAcceleration_TAutoDiffXdU: ...
    def __isub__(self, arg0: SpatialAcceleration_TAutoDiffXdU) -> SpatialAcceleration_TAutoDiffXdU: ...
    def __mul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialAcceleration_TAutoDiffXdU: ...
    def __neg__(self) -> SpatialAcceleration_TAutoDiffXdU: ...
    def __rmul__(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> SpatialAcceleration_TAutoDiffXdU: ...
    def __sub__(self, arg0: SpatialAcceleration_TAutoDiffXdU) -> SpatialAcceleration_TAutoDiffXdU: ...

class _TemporaryName_N5drake9multibody19SpatialAccelerationINS_8symbolic10ExpressionEEE:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, alpha: numpy.ndarray[object[3, 1]], a: numpy.ndarray[object[3, 1]]) -> None: ...
    @overload
    def __init__(self, A: numpy.ndarray[object[6, 1]]) -> None: ...
    def ComposeWithMovingFrameAcceleration(self, position_of_moving_frame: numpy.ndarray[object[3, 1]], angular_velocity_of_this_frame: numpy.ndarray[object[3, 1]], velocity_of_moving_frame: SpatialVelocity_TExpressionU, acceleration_of_moving_frame: SpatialAcceleration_TExpressionU) -> SpatialAcceleration_TExpressionU: ...
    def Rotate(self, R_FE: pydrake.math.RotationMatrix_TExpressionU) -> SpatialAcceleration_TExpressionU: ...
    def SetZero(self) -> SpatialAcceleration_TExpressionU: ...
    def Shift(self, offset: numpy.ndarray[object[3, 1]], angular_velocity_of_this_frame: numpy.ndarray[object[3, 1]]) -> SpatialAcceleration_TExpressionU: ...
    def ShiftWithZeroAngularVelocity(self, offset: numpy.ndarray[object[3, 1]]) -> SpatialAcceleration_TExpressionU: ...
    @staticmethod
    def Zero() -> SpatialAcceleration_TExpressionU: ...
    def get_coeffs(self) -> numpy.ndarray[object[6, 1]]: ...
    def rotational(self) -> numpy.ndarray[object[3, 1]]: ...
    def translational(self) -> numpy.ndarray[object[3, 1]]: ...
    def __add__(self, arg0: SpatialAcceleration_TExpressionU) -> SpatialAcceleration_TExpressionU: ...
    def __copy__(self) -> SpatialAcceleration_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> SpatialAcceleration_TExpressionU: ...
    def __iadd__(self, arg0: SpatialAcceleration_TExpressionU) -> SpatialAcceleration_TExpressionU: ...
    def __imul__(self, arg0: pydrake.symbolic.Expression) -> SpatialAcceleration_TExpressionU: ...
    def __isub__(self, arg0: SpatialAcceleration_TExpressionU) -> SpatialAcceleration_TExpressionU: ...
    def __mul__(self, arg0: pydrake.symbolic.Expression) -> SpatialAcceleration_TExpressionU: ...
    def __neg__(self) -> SpatialAcceleration_TExpressionU: ...
    def __rmul__(self, arg0: pydrake.symbolic.Expression) -> SpatialAcceleration_TExpressionU: ...
    def __sub__(self, arg0: SpatialAcceleration_TExpressionU) -> SpatialAcceleration_TExpressionU: ...



"""
Provides some useful systems using ipywidgets and MultibodyPlant.

This is gui code; to test changes, please manually run
//bindings/pydrake/multibody/examples/jupyter_widgets_examples.ipynb.
"""

from functools import partial

from IPython.display import display
from ipywidgets import FloatSlider, Layout
import numpy as np

from pydrake.common.jupyter import process_ipywidget_events
from pydrake.multibody.tree import JointIndex
from pydrake.systems.framework import PublishEvent, VectorSystem


class JointSliders(VectorSystem):
    """
    Provides a simple ipywidgets gui with one slider per joint of the
    MultibodyPlant.  Any positions that are not associated with joints (e.g.
    floating-base "mobilizers") are held constant at the default value
    obtained from robot.CreateDefaultContext().

    .. pydrake_system::

        name: JointSliders
        output_ports:
        - positions
    """

    def __init__(
        self,
        robot,
        lower_limit=-10.0,
        upper_limit=10.0,
        resolution=0.01,
        length=200,
        update_period_sec=0.005,
    ):
        """ "
        Args:
            robot:       A MultibodyPlant.
            lower_limit: A scalar or vector of length robot.num_positions().
                         The lower limit of the slider will be the maximum
                         value of this number and any limit specified in the
                         Joint.
            upper_limit: A scalar or vector of length robot.num_positions().
                         The upper limit of the slider will be the minimum
                         value of this number and any limit specified in the
                         Joint.
            resolution:  A scalar or vector of length robot.num_positions()
                         that specifies the discretization of the slider.
            length:      The length of the sliders.
            update_period_sec: Specifies how often the window update() method
                         gets called.
        """
        VectorSystem.__init__(
            self, 0, robot.num_positions(), direct_feedthrough=False
        )

        # The widgets themselves have undeclared state.  For now, we accept it,
        # and simply disable caching on the output port.
        self.get_output_port(0).disable_caching_by_default()

        def _reshape(x, num):
            x = np.array(x)
            assert len(x.shape) <= 1
            return np.array(x) * np.ones(num)

        lower_limit = _reshape(lower_limit, robot.num_positions())
        upper_limit = _reshape(upper_limit, robot.num_positions())
        resolution = _reshape(resolution, robot.num_positions())

        # Schedule window updates in either case (new or existing window):
        self.DeclarePeriodicEvent(
            update_period_sec, 0.0, PublishEvent(self._process_event_queue)
        )

        self._slider = []
        self._slider_position_start = []
        context = robot.CreateDefaultContext()
        self._default_position = robot.GetPositions(context)

        k = 0
        for i in robot.GetJointIndices():
            joint = robot.get_joint(JointIndex(i))
            low = joint.position_lower_limits()
            upp = joint.position_upper_limits()
            for j in range(joint.num_positions()):
                index = joint.position_start() + j
                description = joint.name()
                if joint.num_positions() > 1:
                    description += f"[{j}]"
                self._slider_position_start.append(index)
                self._slider.append(
                    FloatSlider(
                        value=self._default_position[index],
                        min=max(low[j], lower_limit[k]),
                        max=min(upp[j], upper_limit[k]),
                        step=resolution[k],
                        continuous_update=True,
                        description=description,
                        style={"description_width": "initial"},
                        layout=Layout(width=f"'{length}'"),
                    )
                )
                display(self._slider[k])
                k += 1

    def set_positions(self, q):
        """
        Set all robot positions; comparable to MultibodyPlant.SetPositions.
        Note that we only have sliders for joint positions, but the
        MultibodyPlant positions many include non-joint positions.  For
        example, models have a floating-base mobilizer by default (unless the
        MultibodyPlant explicitly welds the base to the world), and so have 7
        positions corresponding to the quaternion representation of that
        floating-base position, but not to any joint.

        Args:
            q: a vector whose length is robot.num_positions().
        """
        self._default_position[:] = q
        for i in range(len(self._slider)):
            self._slider[i].value = q[self._slider_position_start[i]]

    def set_joint_positions(self, q):
        """
        Set the slider positions to the values in q.  A list of positions which
        must be the same length as the number of positions ASSOCIATED WITH
        JOINTS in the MultibodyPlant.  This does not include, e.g.,
        floating-base coordinates, which will be assigned a default value.

        Args:
            q: a vector whose length is the same as the number of joint
            positions (also the number of sliders) for the robot.
        """
        assert len(q) == len(self._slider)
        for i in range(len(self._slider)):
            self._slider[i].value = q[i]

    def _process_event_queue(self, unused_context, unused_event):
        process_ipywidget_events()

    def DoCalcVectorOutput(self, context, unused, unused2, output):
        output[:] = self._default_position
        for i in range(len(self._slider)):
            output[self._slider_position_start[i]] = self._slider[i].value


def MakeJointSlidersThatPublishOnCallback(
    plant,
    publishing_system,
    root_context,
    my_callback=None,
    lower_limit=-10.0,
    upper_limit=10.0,
    resolution=0.01,
    length=200,
    continuous_update=True,
):
    """
    Creates an ipywidget slider for each joint in the plant.  Unlike the
    JointSliders System, we do not expect this to be used in a Simulator.  It
    simply updates the context and calls Publish directly from the slider
    callback.

    Args:
        plant:        A MultibodyPlant.
        publishing_system: The System whose Publish method will be called.  Can
                           be the entire Diagram, but can also be a subsystem.
        root_context: A mutable root Context of the Diagram containing both the
                      ``plant`` and the ``publishing_system``; we will extract
                      the subcontext's using `GetMyContextFromRoot`.
        my_callback:  An optional additional callback function that will be
                      called once immediately and again whenever the sliders
                      are moved, using ``my_callback(plant_context)``.  This
                      can be useful, e.g. for outputting text that prints the
                      current end-effector Jacobian, or for showing a rendered
                      image from a camera.
        lower_limit:  A scalar or vector of length robot.num_positions().
                      The lower limit of the slider will be the maximum
                      value of this number and any limit specified in the
                      Joint.
        upper_limit:  A scalar or vector of length robot.num_positions().
                      The upper limit of the slider will be the minimum
                      value of this number and any limit specified in the
                      Joint.
        resolution:   A scalar or vector of length robot.num_positions()
                      that specifies the step argument of the FloatSlider.
        length:       The length of the sliders, which will be passed as a
                      string to the CSS width field and can be any valid CSS
                      entry (e.g. 100, 100px).
        continuous_update: The continuous_update field for the FloatSliders.
                      The default ``True`` means that this method will publish/
                      callback as the sliders are dragged.  ``False`` means
                      that the publish/callback will only happen once the user
                      finishes dragging the slider.

    Returns:
        A list of the slider widget objects that are created.

    Note: Some publishers (like MeshcatVisualizer) use an initialization event
    to "load" the geometry.  You should call that *before* calling this method
    (e.g. with `meshcat.load()`).
    """

    def _broadcast(x, num):
        x = np.array(x)
        assert len(x.shape) <= 1
        return np.array(x) * np.ones(num)

    lower_limit = _broadcast(lower_limit, plant.num_positions())
    upper_limit = _broadcast(upper_limit, plant.num_positions())
    resolution = _broadcast(resolution, plant.num_positions())

    publishing_context = publishing_system.GetMyContextFromRoot(root_context)
    plant_context = plant.GetMyContextFromRoot(root_context)
    positions = plant.GetPositions(plant_context)

    # Publish once immediately.
    publishing_system.ForcedPublish(publishing_context)
    if my_callback:
        my_callback(plant_context)

    def _slider_callback(change, index):
        positions[index] = change.new
        plant.SetPositions(plant_context, positions)
        publishing_system.Publish(publishing_context)
        if my_callback:
            my_callback(plant_context)

    slider_widgets = []
    slider_num = 0
    for i in plant.GetJointIndices():
        joint = plant.get_joint(JointIndex(i))
        low = joint.position_lower_limits()
        upp = joint.position_upper_limits()
        for j in range(joint.num_positions()):
            index = joint.position_start() + j
            description = joint.name()
            if joint.num_positions() > 1:
                description += f"[{j}]"
            slider = FloatSlider(
                value=positions[index],
                min=max(low[j], lower_limit[slider_num]),
                max=min(upp[j], upper_limit[slider_num]),
                step=resolution[slider_num],
                continuous_update=continuous_update,
                description=description,
                style={"description_width": "initial"},
                layout=Layout(width=f"'{length}'"),
            )
            slider.observe(
                partial(_slider_callback, index=index), names="value"
            )
            display(slider)
            slider_widgets.append(slider)
            slider_num += 1

    return slider_widgets



import numpy
import os
import pydrake.common.schema
import pydrake.geometry
import pydrake.math
import pydrake.multibody.tree
import pydrake.systems.framework
from typing import ClassVar, overload

class AddCollisionFilterGroup:
    __fields__: ClassVar[tuple] = ...  # read-only
    ignored_collision_filter_groups: list[str]
    member_groups: list[str]
    members: list[str]
    model_namespace: str | None
    name: str
    def __init__(self, **kwargs) -> None: ...
    def __copy__(self) -> AddCollisionFilterGroup: ...
    def __deepcopy__(self, arg0: dict) -> AddCollisionFilterGroup: ...

class AddDirectives:
    __fields__: ClassVar[tuple] = ...  # read-only
    file: str
    model_namespace: str | None
    def __init__(self, **kwargs) -> None: ...
    def __copy__(self) -> AddDirectives: ...
    def __deepcopy__(self, arg0: dict) -> AddDirectives: ...

class AddFrame:
    __fields__: ClassVar[tuple] = ...  # read-only
    X_PF: pydrake.common.schema.Transform
    name: str
    def __init__(self, **kwargs) -> None: ...
    def __copy__(self) -> AddFrame: ...
    def __deepcopy__(self, arg0: dict) -> AddFrame: ...

class AddModel:
    __fields__: ClassVar[tuple] = ...  # read-only
    default_free_body_pose: dict[str, pydrake.common.schema.Transform]
    default_joint_positions: dict[str, numpy.ndarray[numpy.float64[m, 1]]]
    file: str
    name: str
    def __init__(self, **kwargs) -> None: ...
    def __copy__(self) -> AddModel: ...
    def __deepcopy__(self, arg0: dict) -> AddModel: ...

class AddModelInstance:
    __fields__: ClassVar[tuple] = ...  # read-only
    name: str
    def __init__(self, **kwargs) -> None: ...
    def __copy__(self) -> AddModelInstance: ...
    def __deepcopy__(self, arg0: dict) -> AddModelInstance: ...

class AddWeld:
    __fields__: ClassVar[tuple] = ...  # read-only
    X_PC: pydrake.common.schema.Transform | None
    child: str
    parent: str
    def __init__(self, **kwargs) -> None: ...
    def __copy__(self) -> AddWeld: ...
    def __deepcopy__(self, arg0: dict) -> AddWeld: ...

class CollisionFilterGroups:
    def __init__(self) -> None: ...
    def AddExclusionPair(self, pair: tuple[str]) -> None: ...
    def AddGroup(self, name: str, members: set[str]) -> None: ...
    def empty(self) -> bool: ...
    def exclusion_pairs(self) -> set[tuple[str]]: ...
    def groups(self) -> dict[str, set[str]]: ...

class ModelDirective:
    __fields__: ClassVar[tuple] = ...  # read-only
    add_collision_filter_group: AddCollisionFilterGroup | None
    add_directives: AddDirectives | None
    add_frame: AddFrame | None
    add_model: AddModel | None
    add_model_instance: AddModelInstance | None
    add_weld: AddWeld | None
    def __init__(self, **kwargs) -> None: ...
    def __copy__(self) -> ModelDirective: ...
    def __deepcopy__(self, arg0: dict) -> ModelDirective: ...

class ModelDirectives:
    __fields__: ClassVar[tuple] = ...  # read-only
    directives: list[ModelDirective]
    def __init__(self, **kwargs) -> None: ...
    def __copy__(self) -> ModelDirectives: ...
    def __deepcopy__(self, arg0: dict) -> ModelDirectives: ...

class ModelInstanceInfo:
    def __init__(self, *args, **kwargs) -> None: ...
    @property
    def X_PC(self) -> pydrake.math.RigidTransform: ...
    @property
    def child_frame_name(self) -> str: ...
    @property
    def model_instance(self) -> pydrake.multibody.tree.ModelInstanceIndex: ...
    @property
    def model_name(self) -> str: ...
    @property
    def model_path(self) -> str: ...
    @property
    def parent_frame_name(self) -> str: ...

class PackageMap:
    class RemoteParams:
        __fields__: ClassVar[tuple] = ...  # read-only
        archive_type: str | None
        sha256: str
        strip_prefix: str | None
        urls: list[str]
        def __init__(self, **kwargs) -> None: ...
        def ToJson(self) -> str: ...
        def __copy__(self) -> PackageMap.RemoteParams: ...
        def __deepcopy__(self, arg0: dict) -> PackageMap.RemoteParams: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: PackageMap) -> None: ...
    def Add(self, package_name: str, package_path: os.PathLike) -> None: ...
    def AddMap(self, other_map: PackageMap) -> None: ...
    def AddPackageXml(self, filename: os.PathLike) -> None: ...
    def AddRemote(self, package_name: str, params: PackageMap.RemoteParams) -> None: ...
    def Contains(self, package_name: str) -> bool: ...
    def GetPackageNames(self) -> list[str]: ...
    def GetPath(self, package_name: str) -> str: ...
    @staticmethod
    def MakeEmpty() -> PackageMap: ...
    def PopulateFromEnvironment(self, environment_variable: str) -> None: ...
    def PopulateFromFolder(self, path: os.PathLike) -> None: ...
    def PopulateFromRosPackagePath(self) -> None: ...
    def Remove(self, package_name: str) -> None: ...
    def ResolveUrl(self, url: str) -> str: ...
    def size(self) -> int: ...
    def __copy__(self) -> PackageMap: ...
    def __deepcopy__(self, arg0: dict) -> PackageMap: ...

class Parser:
    @overload
    def __init__(self, plant, scene_graph: pydrake.geometry.SceneGraph = ..., model_name_prefix: str = ...) -> None: ...
    @overload
    def __init__(self, plant, model_name_prefix: str) -> None: ...
    @overload
    def __init__(self, builder: pydrake.systems.framework.DiagramBuilder, plant=..., scene_graph: pydrake.geometry.SceneGraph = ..., model_name_prefix: str = ...) -> None: ...
    def AddModels(self, file_name: os.PathLike) -> list[pydrake.multibody.tree.ModelInstanceIndex]: ...
    def AddModelsFromString(self, file_contents: str, file_type: str) -> list[pydrake.multibody.tree.ModelInstanceIndex]: ...
    def AddModelsFromUrl(self, url: str) -> list[pydrake.multibody.tree.ModelInstanceIndex]: ...
    def GetAutoRenaming(self) -> bool: ...
    def GetCollisionFilterGroups(self) -> CollisionFilterGroups: ...
    def SetAutoRenaming(self, value: bool) -> None: ...
    def SetStrictParsing(self) -> None: ...
    def builder(self) -> pydrake.systems.framework.DiagramBuilder: ...
    def package_map(self) -> PackageMap: ...
    def plant(self, *args, **kwargs): ...
    def scene_graph(self) -> pydrake.geometry.SceneGraph: ...

def FlattenModelDirectives(directives: ModelDirectives, package_map: PackageMap) -> ModelDirectives: ...
@overload
def GetScopedFrameByName(plant, full_name: str) -> pydrake.multibody.tree.Frame: ...
@overload
def GetScopedFrameByName(plant, full_name: str) -> pydrake.multibody.tree.Frame_TAutoDiffXdU: ...
@overload
def GetScopedFrameByName(plant, full_name: str) -> pydrake.multibody.tree.Frame_TExpressionU: ...
@overload
def GetScopedFrameByNameMaybe(plant, full_name: str) -> pydrake.multibody.tree.Frame: ...
@overload
def GetScopedFrameByNameMaybe(plant, full_name: str) -> pydrake.multibody.tree.Frame_TAutoDiffXdU: ...
@overload
def GetScopedFrameByNameMaybe(plant, full_name: str) -> pydrake.multibody.tree.Frame_TExpressionU: ...
def LoadModelDirectives(filename: os.PathLike) -> ModelDirectives: ...
def LoadModelDirectivesFromString(model_directives: str) -> ModelDirectives: ...
@overload
def ProcessModelDirectives(directives: ModelDirectives, parser: Parser) -> list[ModelInstanceInfo]: ...
@overload
def ProcessModelDirectives(directives: ModelDirectives, plant, parser: Parser = ...) -> list[ModelInstanceInfo]: ...



"""
Provides support for using ipywidgets with the systems framework, and a number
of useful widget systems.

This is gui code; to test changes, please manually run
//bindings/pydrake/systems/jupyter_widgets_examples.ipynb.
"""

import asyncio
import sys
from warnings import warn

from IPython import get_ipython

# Note: The implementation below was inspired by
# https://github.com/Kirill888/jupyter-ui-poll , though I suspect it can be
# optimized.
#
# For reference,
# https://ipywidgets.readthedocs.io/en/latest/examples/Widget%20Asynchronous.html  # noqa
# describes the problem but it only offers the solution of using separate
# threads for execution; a workflow that we do not wish to impose on users.


def process_ipywidget_events(num_events_to_process=1):
    """
    Allows the kernel to process GUI events.  This is required in order to
    process ipywidget updates inside a simulation loop.
    """

    shell = get_ipython()
    # Ok to do nothing if running from console.
    if shell is None or not hasattr(shell, "kernel"):
        return
    kernel = shell.kernel
    events = []
    old_handler = kernel.shell_handlers["execute_request"]
    kernel.shell_handlers["execute_request"] = lambda *e: events.append(e)
    current_parent = (kernel._parent_ident, kernel._parent_header)

    def _get_shell_stream(kernel):
        # Return the zmq stream that receives messages for the main shell.
        # Only ipykernel>=7.0.0 supports subshells, so this attribute won't be
        # defined in previous versions.
        # TODO(tyler-yankee): Once we support ipykernel>=7.0.0 on all platforms,
        # this additional check can be removed.
        if (
            hasattr(kernel, "_supports_kernel_subshells")
            and kernel._supports_kernel_subshells
        ):
            manager = kernel.shell_channel_thread.manager
            socket_pair = manager.get_shell_channel_to_subshell_pair(None)
            return socket_pair.to_stream
        return kernel.shell_stream

    for _ in range(num_events_to_process):
        # Ensure stdout still happens in the same cell.
        kernel.set_parent(*current_parent)
        _get_shell_stream(kernel).flush(limit=1)
        kernel.set_parent(*current_parent)

    kernel.shell_handlers["execute_request"] = old_handler

    def _replay_events(shell, events):
        kernel = shell.kernel
        sys.stdout.flush()
        sys.stderr.flush()
        for stream, ident, parent in events:
            kernel.set_parent(ident, parent)
            kernel.execute_request(stream, ident, parent)

    if len(events) > 0:
        loop = asyncio.get_event_loop()
        if loop.is_running():
            loop.call_soon(lambda: _replay_events(shell, events))
        else:
            warn(
                "One of your components is attempting to use pydrake's "
                "process_ipywidget_events function. However, this IPython "
                "kernel is not asyncio-based. This means the following:\n"
                "  (1) Once your block cell is done executing, future cells "
                "will *not* execute, but it may appear like they are still "
                "executing ([*]).\n"
                "  (2) Your Jupyter UI may break. If you find your UI to be "
                "unresponsive, you may need to restart the UI itself.\n"
                "To avoid this behavior, avoid requesting execution of "
                "future cells before or during execution of this cell."
            )



"""This (private) module is like pydrake.all, but with an even wider charter.

The pydrake.all module merges all of Drake's _stable_ modules (e.g., it does
not incorporate any of the `pydrake.examples.*`).

On the other hand, this module imports all of Drake's _public_ modules (which
are a superset of the stable modules). Importing all modules is a prerequisite
of generating our website docs, *.pyi type stub files, etc.

Anytime pydrake gains a new public module, that module needs to be added to
either pydrake.all or this file.

TODO(jwnimmer-tri) Nobody ever remembers to add their module to the lists.
We need some kind of automated cross-check to enforce the rule.
"""

import importlib

# Start with all of the stable modules.
importlib.__import__("pydrake.all")

# Add the remaining public modules.
importlib.__import__("pydrake.common.cpp_param")
importlib.__import__("pydrake.common.cpp_template")
importlib.__import__("pydrake.examples")
importlib.__import__("pydrake.examples.gym.play_cart_pole")
importlib.__import__("pydrake.examples.gym.train_cart_pole")
importlib.__import__("pydrake.gym")
importlib.__import__("pydrake.tutorials")



# See `ExecuteExtraPythonCode` in `pydrake_pybind.h` for usage details and
# rationale.

# ruff: noqa: F821 (undefined-name). This file is only a fragment.

# This is a python reimplementation of drake::lcm::Subscriber.  We reimplement
# (rather than bind) the C++ class because we want message() to be a python LCM
# message, not a C++ object.
class Subscriber:
    """Subscribes to and stores a copy of the most recent message on a given
    channel, for some message type.  This class does NOT provide any mutex
    behavior for multi-threaded locking; it should only be used in cases where
    the governing DrakeLcmInterface.HandleSubscriptions is called from the same
    thread that owns all copies of this object.
    """

    def __init__(self, lcm, channel, lcm_type):
        """Creates a subscriber and subscribes to `channel` on `lcm`.

        Args:
            lcm: LCM service instance (a pydrake.lcm.DrakeLcmInterface).
            channel: LCM channel name.
            lcm_type: Python class generated by lcmgen.
        """
        self.lcm_type = lcm_type
        self.clear()
        lcm.Subscribe(channel=channel, handler=self._handler)

    def clear(self):
        self.count = 0
        self.raw = []
        self.message = self.lcm_type()

    def _handler(self, raw):
        self.count += 1
        self.raw = raw
        self.message = self.lcm_type.decode(raw)



import numpy
import os
import pydrake.autodiffutils
from . import eigen_geometry as eigen_geometry, schema as schema, value as value
from typing import Any, Callable, ClassVar, overload

configure_logging: Callable
kDrakeAssertIsArmed: bool
pretty_class_name: Callable
use_native_cpp_logging: Callable

class MemoryFile:
    __fields__: ClassVar[tuple] = ...  # read-only
    def __init__(self, contents: bytes | str = ..., extension: str = ..., filename_hint: str = ...) -> None: ...
    @staticmethod
    def Make(path: os.PathLike) -> MemoryFile: ...
    def contents(self) -> bytes: ...
    @overload
    def extension(self) -> str: ...
    @overload
    def extension(self, aspassedtotheconstructor) -> Any: ...
    def filename_hint(self) -> str: ...
    def sha256(self) -> Sha256: ...
    def __copy__(self) -> MemoryFile: ...
    def __deepcopy__(self, arg0: dict) -> MemoryFile: ...
    def __setattr__(self, arg0: str, arg1: object) -> None: ...

class Parallelism:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, parallelize: bool) -> None: ...
    @overload
    def __init__(self, num_threads: int) -> None: ...
    @staticmethod
    def Max() -> Parallelism: ...
    def num_threads(self) -> int: ...
    def __copy__(self) -> Parallelism: ...
    def __deepcopy__(self, arg0: dict) -> Parallelism: ...

class RandomDistribution:
    __members__: ClassVar[dict] = ...  # read-only
    __entries: ClassVar[dict] = ...
    kExponential: ClassVar[RandomDistribution] = ...
    kGaussian: ClassVar[RandomDistribution] = ...
    kUniform: ClassVar[RandomDistribution] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class RandomGenerator:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, seed: int) -> None: ...
    def __call__(self) -> int: ...

class Sha256:
    def __init__(self) -> None: ...
    @staticmethod
    def Checksum(data: bytes | str) -> Sha256: ...
    @staticmethod
    def Parse(arg0: str) -> Sha256 | None: ...
    def to_string(self) -> str: ...
    def __copy__(self) -> Sha256: ...
    def __deepcopy__(self, arg0: dict) -> Sha256: ...
    def __eq__(self, arg0: Sha256) -> bool: ...
    def __lt__(self, arg0: Sha256) -> bool: ...
    def __ne__(self, arg0: Sha256) -> bool: ...

class ToleranceType:
    __members__: ClassVar[dict] = ...  # read-only
    __entries: ClassVar[dict] = ...
    kAbsolute: ClassVar[ToleranceType] = ...
    kRelative: ClassVar[ToleranceType] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class _MangledName:
    UNICODE_COMMA: ClassVar[str] = ...
    UNICODE_LEFT_BRACKET: ClassVar[str] = ...
    UNICODE_PERIOD: ClassVar[str] = ...
    UNICODE_RIGHT_BRACKET: ClassVar[str] = ...
    demangle: ClassVar[Callable] = ...
    mangle: ClassVar[Callable] = ...
    module_getattr: ClassVar[Callable] = ...

@overload
def CalcProbabilityDensity(distribution: RandomDistribution, x: numpy.ndarray[numpy.float64[m, 1]]) -> float: ...
@overload
def CalcProbabilityDensity(distribution: RandomDistribution, x: numpy.ndarray[object[m, 1]]) -> pydrake.autodiffutils.AutoDiffXd: ...
def FindResourceOrThrow(resource_path: str) -> str: ...
def GetDrakePath() -> object: ...
def temp_directory() -> str: ...
def trigger_an_assertion_failure() -> None: ...
